.elementor-7230 .elementor-element.elementor-element-2dd62bc{text-align:center;}.elementor-7230 .elementor-element.elementor-element-2dd62bc .elementor-heading-title{color:#111111;font-family:"Jost", Sans-serif;font-size:36px;font-weight:500;}.elementor-7230 .elementor-element.elementor-element-997c895 .elementor-spacer-inner{--spacer-size:32px;}.elementor-7230 .elementor-element.elementor-element-bdb77e1{text-align:center;color:#525252;font-family:"Jost", Sans-serif;font-size:18px;}.elementor-7230 .elementor-element.elementor-element-f84519b .elementor-spacer-inner{--spacer-size:48px;}