.elementor-497 .elementor-element.elementor-element-591aebd1:not(.elementor-motion-effects-element-type-background), .elementor-497 .elementor-element.elementor-element-591aebd1 > .elementor-motion-effects-container > .elementor-motion-effects-layer{background-image:url("https://i1.wp.com/demo4.drfuri.com/razzi/wp-content/uploads/sites/14/2020/12/bg_comingsoon-scaled-1.jpg");}.elementor-497 .elementor-element.elementor-element-591aebd1{transition:background 0.3s, border 0.3s, border-radius 0.3s, box-shadow 0.3s;}.elementor-497 .elementor-element.elementor-element-591aebd1 > .elementor-background-overlay{transition:background 0.3s, border-radius 0.3s, opacity 0.3s;}.elementor-497 .elementor-element.elementor-element-48173100 .elementor-spacer-inner{--spacer-size:10px;}.elementor-497 .elementor-element.elementor-element-3d138f97 .elementor-heading-title{color:#FFFFFF;font-family:"Jost", Sans-serif;font-size:28px;font-weight:600;}.elementor-497 .elementor-element.elementor-element-520c2e15 .elementor-repeater-item-6337913.elementor-social-icon{background-color:#02010100;}.elementor-497 .elementor-element.elementor-element-520c2e15 .elementor-repeater-item-a3595b6.elementor-social-icon{background-color:#02010100;}.elementor-497 .elementor-element.elementor-element-520c2e15 .elementor-repeater-item-97aec2a.elementor-social-icon{background-color:#02010100;}.elementor-497 .elementor-element.elementor-element-520c2e15 .elementor-repeater-item-46e4759.elementor-social-icon{background-color:#02010100;}.elementor-497 .elementor-element.elementor-element-520c2e15{--grid-template-columns:repeat(0, auto);--icon-size:14px;--grid-column-gap:0px;--grid-row-gap:0px;}.elementor-497 .elementor-element.elementor-element-520c2e15 .elementor-widget-container{text-align:right;}.elementor-497 .elementor-element.elementor-element-33f3e03c .elementor-spacer-inner{--spacer-size:107px;}.elementor-497 .elementor-element.elementor-element-58e23c0d{text-align:center;}.elementor-497 .elementor-element.elementor-element-58e23c0d .elementor-heading-title{color:#FFFFFF;font-family:"Jost", Sans-serif;font-size:44px;font-weight:500;}.elementor-497 .elementor-element.elementor-element-558712fc .elementor-spacer-inner{--spacer-size:17px;}.elementor-497 .elementor-element.elementor-element-7dd8408c{text-align:center;color:#FFFFFF;}.elementor-497 .elementor-element.elementor-element-53ba990d .elementor-spacer-inner{--spacer-size:48px;}.elementor-497 .elementor-element.elementor-element-599d1cba .razzi-time-countdown{justify-content:center;}.elementor-497 .elementor-element.elementor-element-599d1cba .razzi-time-countdown .timer .digits{color:#FFFFFF;}.elementor-497 .elementor-element.elementor-element-599d1cba .razzi-time-countdown .timer .text{color:#FFFFFF;}.elementor-497 .elementor-element.elementor-element-599d1cba .razzi-time-countdown .timer .divider{color:#FFFFFF;}.elementor-497 .elementor-element.elementor-element-2f21b09 .elementor-spacer-inner{--spacer-size:64px;}.elementor-497 .elementor-element.elementor-element-37714e3b .razzi-newsletter .mc4wp-form-fields{margin:auto;}.elementor-497 .elementor-element.elementor-element-37714e3b .razzi-newsletter .mc4wp-form input[type="email"]{color:#FFFFFF;}.elementor-497 .elementor-element.elementor-element-37714e3b .mc4wp-form input[type=text], .elementor-497 .elementor-element.elementor-element-37714e3b .mc4wp-form input[type=email]{background-color:#1F1F1F66;border-style:none;}@media(max-width:440px){.elementor-497 .elementor-element.elementor-element-599d1cba .razzi-time-countdown .timer .digits{font-size:30px;}}