.elementor-13807 .elementor-element.elementor-element-b107d6d{margin-top:-80px;margin-bottom:0px;}.elementor-13807 .elementor-element.elementor-element-007f153{margin-top:-80px;margin-bottom:0px;}@media(max-width:440px){.elementor-13807 .elementor-element.elementor-element-007f153{margin-top:0px;margin-bottom:0px;padding:0px 0px 0px 0px;}}