.elementor-13214 .elementor-element.elementor-element-7469b19{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-f57eedb{text-align:center;}.elementor-13214 .elementor-element.elementor-element-f57eedb > .elementor-widget-container{margin:0px 0px 15px 0px;}.elementor-13214 .elementor-element.elementor-element-391e47b{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-4115a30{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-7197496{text-align:left;}.elementor-13214 .elementor-element.elementor-element-7197496 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13214 .elementor-element.elementor-element-7197496 > .elementor-widget-container{margin:020px 0px 0px 0px;padding:0px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-d28fd8a{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-d28fd8a > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-302f355 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-02b8133{text-align:left;}.elementor-13214 .elementor-element.elementor-element-02b8133 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13214 .elementor-element.elementor-element-02b8133 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-3df4477{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-3df4477 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-cd37892 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-1014c21{text-align:left;}.elementor-13214 .elementor-element.elementor-element-1014c21 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13214 .elementor-element.elementor-element-1014c21 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-30c3272{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-30c3272 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-869c773 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-1066f3a{text-align:left;}.elementor-13214 .elementor-element.elementor-element-1066f3a .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13214 .elementor-element.elementor-element-1066f3a > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-0fef202{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-0fef202 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13214 .elementor-element.elementor-element-e24b27a{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13214 .elementor-element.elementor-element-dedf513 > .elementor-widget-container{margin:020px 0px 0px 0px;}@media(max-width:440px){.elementor-13214 .elementor-element.elementor-element-02b8133{text-align:center;}.elementor-13214 .elementor-element.elementor-element-1014c21{text-align:center;}.elementor-13214 .elementor-element.elementor-element-1066f3a{text-align:center;}}