.elementor-13228 .elementor-element.elementor-element-e8cad80{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-ee4423a{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-5b26e66{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-edf51ba{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-8751732 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:600;-webkit-text-stroke-color:#000;stroke:#000;}.elementor-13228 .elementor-element.elementor-element-8751732 > .elementor-widget-container{margin:015px 0px 0px 0px;}.elementor-13228 .elementor-element.elementor-element-09eead5{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-4634391{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-ece61b9 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:600;}.elementor-13228 .elementor-element.elementor-element-ece61b9 > .elementor-widget-container{margin:015px 0px 0px 0px;}.elementor-13228 .elementor-element.elementor-element-73cf8ab{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-f201fa8 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:600;}.elementor-13228 .elementor-element.elementor-element-f201fa8 > .elementor-widget-container{margin:015px 0px 0px 0px;}.elementor-13228 .elementor-element.elementor-element-4562936{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13228 .elementor-element.elementor-element-71137b7 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:600;}.elementor-13228 .elementor-element.elementor-element-71137b7 > .elementor-widget-container{margin:015px 0px 0px 0px;}.elementor-13228 .elementor-element.elementor-element-f2c3b47{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}