.elementor-13217 .elementor-element.elementor-element-25abfa0{padding:0px 15px 0px 15px;}.elementor-13217 .elementor-element.elementor-element-f816fe5{text-align:justify;color:var( --e-global-color-secondary );font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-bc-flex-widget .elementor-13217 .elementor-element.elementor-element-5c7504a.elementor-column .elementor-widget-wrap{align-items:center;}.elementor-13217 .elementor-element.elementor-element-5c7504a.elementor-column.elementor-element[data-element_type="column"] > .elementor-widget-wrap.elementor-element-populated{align-content:center;align-items:center;}.elementor-13217 .elementor-element.elementor-element-7c2938f{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-fe4189b{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-6b93bdc{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-df44ba0{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-c5eb6db{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-2b53a5f{text-align:left;}.elementor-13217 .elementor-element.elementor-element-2b53a5f .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13217 .elementor-element.elementor-element-2b53a5f > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13217 .elementor-element.elementor-element-24e48bf{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-9fc1d77{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-f7867c9{text-align:left;}.elementor-13217 .elementor-element.elementor-element-f7867c9 .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13217 .elementor-element.elementor-element-f7867c9 > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13217 .elementor-element.elementor-element-d1aac78{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-f7df922{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-21b5323{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-0a9ad6e{text-align:left;}.elementor-13217 .elementor-element.elementor-element-0a9ad6e .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13217 .elementor-element.elementor-element-0a9ad6e > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13217 .elementor-element.elementor-element-b3fdc4a{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-b51dc0b{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-6a249cd{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-54bf30f{text-align:left;}.elementor-13217 .elementor-element.elementor-element-54bf30f .elementor-heading-title{font-family:"Playfair Display", Sans-serif;font-weight:300;}.elementor-13217 .elementor-element.elementor-element-54bf30f > .elementor-widget-container{margin:020px 0px 0px 0px;}.elementor-13217 .elementor-element.elementor-element-fa65142{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-8fc195b{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}.elementor-13217 .elementor-element.elementor-element-8af805f{text-align:justify;font-family:"Montserrat", Sans-serif;font-size:16px;font-weight:400;}@media(max-width:440px){.elementor-13217 .elementor-element.elementor-element-2b53a5f{text-align:center;}.elementor-13217 .elementor-element.elementor-element-f7867c9{text-align:center;}.elementor-13217 .elementor-element.elementor-element-0a9ad6e{text-align:center;}.elementor-13217 .elementor-element.elementor-element-54bf30f{text-align:center;}}